@@ -1,8 +1,7 @@
 use crate::file::{self, commit::Commit, File, COMMIT_DATA_ENTRY_SIZE};
 use git_hash::SIZE_OF_SHA1_DIGEST as SHA1_SIZE;
-use git_object::{borrowed, HashKind};
 use std::{
-    convert::{TryFrom, TryInto},
+    convert::TryInto,
     fmt::{Debug, Formatter},
     path::Path,
 };
@@ -28,14 +27,14 @@ impl File {
     /// The kind of hash used in this File.
     ///
     /// Note that it is always conforming to the hash used in the owning repository.
-    pub fn hash_kind(&self) -> HashKind {
-        HashKind::Sha1
+    pub fn hash_kind(&self) -> git_hash::Kind {
+        git_hash::Kind::Sha1
     }
 
     /// Returns 20 bytes sha1 at the given index in our list of (sorted) sha1 hashes.
     /// The position ranges from 0 to self.num_commits()
     // copied from git-odb/src/pack/index/access.rs
-    pub fn id_at(&self, pos: file::Position) -> borrowed::Id<'_> {
+    pub fn id_at(&self, pos: file::Position) -> &git_hash::oid {
         assert!(
             pos.0 < self.num_commits(),
             "expected lexigraphical position less than {}, got {}",
@@ -47,16 +46,16 @@ impl File {
             .try_into()
             .expect("an architecture able to hold 32 bits of integer");
         let start = self.oid_lookup_offset + (pos * SHA1_SIZE);
-        borrowed::Id::try_from(&self.data[start..start + SHA1_SIZE]).expect("20 bytes SHA1 to be alright")
+        git_hash::oid::try_from(&self.data[start..start + SHA1_SIZE]).expect("20 bytes SHA1 to be alright")
     }
 
     /// Return an iterator over all object hashes stored in the base graph.
-    pub fn iter_base_graph_ids(&self) -> impl Iterator<Item = borrowed::Id<'_>> {
+    pub fn iter_base_graph_ids(&self) -> impl Iterator<Item = &git_hash::oid> {
         let start = self.base_graphs_list_offset.unwrap_or(0);
         let base_graphs_list = &self.data[start..start + (SHA1_SIZE * usize::from(self.base_graph_count))];
         base_graphs_list
             .chunks(SHA1_SIZE)
-            .map(|bytes| borrowed::Id::try_from(bytes).expect("20 bytes SHA1 to be alright"))
+            .map(|bytes| git_hash::oid::try_from(bytes).expect("20 bytes SHA1 to be alright"))
     }
 
     /// return an iterator over all commits in this file.
@@ -65,13 +64,14 @@ impl File {
     }
 
     /// Return an iterator over all object hashes stored in this file.
-    pub fn iter_ids(&self) -> impl Iterator<Item = borrowed::Id<'_>> {
+    pub fn iter_ids(&self) -> impl Iterator<Item = &git_hash::oid> {
         (0..self.num_commits()).map(move |i| self.id_at(file::Position(i)))
     }
 
     /// Translate the given object hash to its position within this file, if present.
     // copied from git-odb/src/pack/index/access.rs
-    pub fn lookup(&self, id: borrowed::Id<'_>) -> Option<file::Position> {
+    pub fn lookup(&self, id: impl AsRef<git_hash::oid>) -> Option<file::Position> {
+        let id = id.as_ref();
         let first_byte = usize::from(id.first_byte());
         let mut upper_bound = self.fan[first_byte];
         let mut lower_bound = if first_byte != 0 { self.fan[first_byte - 1] } else { 0 };
